# Reference

<!--
The content of the {eval-rst} block below is generated by the command:
uv run sphinx-apidoc -T -f -t ./docs/templates -o ./docs ./src
from the root directory.

You need to rerun the command when python files are added, deleted or renamed.
Copy the content from the generated
rst files to the {eval-rst} block below and
delete the .rst file afterwards.
-->

```{eval-rst}
datadoc package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   datadoc_editor.frontend
   datadoc_editor.logging_configuration

Submodules
----------

datadoc_editor.app module
------------------

.. automodule:: datadoc_editor.app
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.config module
---------------------

.. automodule:: datadoc_editor.config
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.constants module
------------------------

.. automodule:: datadoc_editor.constants
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.enums module
--------------------

.. automodule:: datadoc_editor.enums
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.state module
--------------------

.. automodule:: datadoc_editor.state
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.utils module
--------------------

.. automodule:: datadoc_editor.utils
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.wsgi module
-------------------

.. automodule:: datadoc_editor.wsgi
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.logging\_configuration package
======================================

Submodules
----------

datadoc_editor.logging\_configuration.json\_formatter module
-----------------------------------------------------

.. automodule:: datadoc_editor.logging_configuration.json_formatter
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.logging\_configuration.logging\_config module
-----------------------------------------------------

.. automodule:: datadoc_editor.logging_configuration.logging_config
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc_editor.logging_configuration
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   datadoc_editor.frontend.callbacks
   datadoc_editor.frontend.components
   datadoc_editor.frontend.fields

Submodules
----------

datadoc_editor.frontend.constants module
---------------------------------

.. automodule:: datadoc_editor.frontend.constants
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc_editor.frontend
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.fields package
===============================

Submodules
----------

datadoc_editor.frontend.fields.display\_base module
--------------------------------------------

.. automodule:: datadoc_editor.frontend.fields.display_base
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.fields.display\_dataset module
-----------------------------------------------

.. automodule:: datadoc_editor.frontend.fields.display_dataset
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.fields.display\_variables module
-------------------------------------------------

.. automodule:: datadoc_editor.frontend.fields.display_variables
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc_editor.frontend.fields
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.components package
===================================

Submodules
----------

datadoc_editor.frontend.components.builders module
-------------------------------------------

.. automodule:: datadoc_editor.frontend.components.builders
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.components.control\_bars module
------------------------------------------------

.. automodule:: datadoc_editor.frontend.components.control_bars
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.components.identifiers module
----------------------------------------------

.. automodule:: datadoc_editor.frontend.components.identifiers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc_editor.frontend.components
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.callbacks package
==================================

Submodules
----------

datadoc_editor.frontend.callbacks.dataset module
-----------------------------------------

.. automodule:: datadoc_editor.frontend.callbacks.dataset
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.callbacks.register\_callbacks module
-----------------------------------------------------

.. automodule:: datadoc_editor.frontend.callbacks.register_callbacks
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.callbacks.utils module
---------------------------------------

.. automodule:: datadoc_editor.frontend.callbacks.utils
   :members:
   :undoc-members:
   :show-inheritance:

datadoc_editor.frontend.callbacks.variables module
-------------------------------------------

.. automodule:: datadoc_editor.frontend.callbacks.variables
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: datadoc_editor.frontend.callbacks
   :members:
   :undoc-members:
   :show-inheritance:
```
